/**
 * Copyright (c) 2010 CA. All rights reserved.
 * 
 * This software and all information contained therein is confidential and proprietary and shall not be duplicated, used, disclosed or
 * disseminated in any way without the express written permission of CA. All authorized reproductions must be marked with this language.
 * 
 * TO THE EXTENT PERMITTED BY APPLICABLE LAW, CA PROVIDES THIS SOFTWARE AS IS WITHOUT WARRANTY OF ANY KIND, INCLUDING WITHOUT LIMITATION,
 * ANY IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NONINFRINGEMENT. IN NO EVENT WILL CA BE LIABLE TO THE END
 * USER OR ANY THIRD PARTY FOR ANY LOSS OR DAMAGE, DIRECT OR INDIRECT, FROM THE USE OF THIS MATERIAL, INCLUDING WITHOUT LIMITATION, LOST
 * PROFITS, BUSINESS INTERRUPTION, GOODWILL, OR LOST DATA, EVEN IF CA IS EXPRESSLY ADVISED OF SUCH LOSS OR DAMAGE.
 */

package com.wily.apm.model.webservices;

import java.rmi.RemoteException;
import java.util.Calendar;

import com.wily.apm.model.webservices.common.DIncidentsResponse;
import com.wily.apm.model.webservices.exception.ApmWebServicesException;



/**
 * This web service provides operations to retrieve
 * CEM Incident information from EM.
 * 
 * @author macdu01
 *
 */
public interface IIncidentsService extends java.rmi.Remote 
{	

	/**
	 * Get all open incidents.
	 * @return DIncidentsResponse object containing array of incidents that are open and EM
	 * date and time at which response was valid.
	 * @throws ApmWebServicesException if unable to access incident information.
	 * @throws RemoteException 
	 */
	public DIncidentsResponse getOpenIncidents() throws ApmWebServicesException, RemoteException;
	
	/**
	 * Get incidents modified (i.e. created, updated or closed) since specified date and time.
	 * 
	 * @param dt date and time used to filter incidents.  Date and time interpreted using EM
	 *  clock.  If in future, no incidents will be returned.
	 * @return DIncidentsResponse object containing array of incidents that are open and EM
	 * date and time at which response was valid.
	 * @throws ApmWebServicesException if unable to access incident information.
	 * @throws RemoteException 
	 */
	public DIncidentsResponse getIncidentsModifiedAfter(Calendar dt) throws ApmWebServicesException, RemoteException;
}